@@ -1009,7 +1009,7 @@ create_rules = function(approval) {
         if (error_details['ExceptionClass'] == 'DuplicateRule') {
             html_check = '<font color="red">The rule that you are trying to create already exists, please go back and choose another DID or RSE.</font>';
         } else if (error_details['ExceptionClass'] == 'RSEWriteBlocked') {
-            html_check = '<font color="red">The RSE that you chose is currently not available for writing. Please check <a href="http://atlas-agis.cern.ch/agis/ddmblacklisting/list/" target="_blank">here</a> for more information.</font>';
+            html_check = '<font color="red">The RSE that you chose is currently not available for writing. Please check <a href="https://atlas-cric.cern.ch/atlas/ddmendpointstatus/list/" target="_blank">here</a> for more information.</font>';
         } else {
             html_check = '<font color="red">' + error_details['ExceptionClass'] + ': ' + error_details['ExceptionMessage'] + '</font>';
         }
@@ -1251,8 +1251,8 @@ create_summary = function(approval) {
     });
     $(dt.column(1).footer()).html(total_copies);
     $(dt.column(2).footer()).html(total_files);
-    $(dt.column(3).footer()).html(filesize(total_size), {'base': 10});
-    $(dt.column(4).footer()).html(filesize(total_requested_size), {'base': 10});
+    $(dt.column(3).footer()).html(filesize(total_size, {'base': 10}));
+    $(dt.column(4).footer()).html(filesize(total_requested_size, {'base': 10}));
 
     dt = $("#dt_summary_rses").DataTable({
         data: rse_data,
